@@ -1,11 +1,14 @@
+import pathlib
 # emojis
 THUMBS_UP = "👍"
 THUMBS_DOWN = "👎"
 ERROR = "❌"
 
 # info
-with open("./version.txt") as r:
-    VERSION = r.read()
+
+ROOT = pathlib.Path(__file__).parent
+with open(ROOT / "version.txt", "r", encoding="utf-8") as f:
+    VERSION = f.read()
 
 BLACKLIST_HELP = """
 Send the name of the commands you want to blacklist the user from.
